<template>
  <a-card
    :bordered="false"
    title="生产设备自主维护点检表"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col :span="6">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="统一编码"
            >
              <a-input
                placeholder="请输入设备统一编码查询"
                v-model="queryParam.num"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="6">
            <a-form-item
              label="查询日期"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <!-- <j-date
                style="width: 100%"
                placeholder="请选择查询日期"
                :showTime="true"
                dateFormat="YYYY-MM"
                v-model="queryParam.dataTime"
              /> -->
              <a-month-picker
                style="width: 100%"
                v-model="queryParam.dataTime"
                dateFormat="YYYY-MM"
                placeholder="请选择查询日期"
              />
            </a-form-item>
          </a-col>
          <!-- <a-col :span="6">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="设备名称"
            >
              <a-input
                placeholder="请输入设备名称查询"
                v-model="queryParam.name"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="6">
            <a-form-item
              label="型号"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                v-model="queryParam.model"
                placeholder="请输入型号"
              ></a-input>
            </a-form-item>
          </a-col> -->
        </a-row>
      </a-form>
    </div>
    <div class="table-operator">
      <a-button
        type="primary"
        @click="searchQuery"
        icon="search"
      >查询</a-button>
      <a-button
        @click="searchReset"
        icon="reload"
      >重置</a-button>
    </div>
    <div>
      <a-table
        ref="table"
        size="small"
        bordered
        rowKey="id"
        :scroll="{ x: 'calc(1800px + 50%)', y: 900 }"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="false"
        :loading="loading"
        @change="handleTableChange"
      >
        <!-- :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'checkbox'}" -->
        <!-- :customRow="clickThenSelect" -->
        <span
          slot="yseNoPrecisionParameters"
          slot-scope="text"
        >
          <a-icon
            type="check"
            style="color: chartreuse;"
            v-if="text==='0'"
          />
          <a-icon
            type="close"
            v-else
            style="color:red;"
          />
        </span>
        <span
          slot="yseNoInspectionStandard"
          slot-scope="text"
        >
          <a-icon
            type="check"
            style="color: chartreuse;"
            v-if="text==='0'"
          />
          <a-icon
            type="close"
            v-else
            style="color:red;"
          />
        </span>
        <span
          slot="yseNoMaintenance2Standard"
          slot-scope="text"
        >
          <a-icon
            type="check"
            style="color: chartreuse;"
            v-if="text==='0'"
          />
          <a-icon
            type="close"
            v-else
            style="color:red;"
          />
        </span>
        <span
          slot="yseNoMaintenance3Standard"
          slot-scope="text"
        >
          <a-icon
            type="check"
            style="color: chartreuse;"
            v-if="text==='0'"
          />
          <a-icon
            type="close"
            v-else
            style="color:red;"
          />
        </span>
      </a-table>
      <!-- <a-table
        ref="table"
        size="small"
        bordered
        rowKey="id"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource2"
        :pagination="ipagination"
        :loading="loading"
        @change="handleTableChange"
      >
      </a-table> -->
    </div>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { mixinDevice } from '@/utils/mixin'
import { getAction } from '@/api/manage'
import EquipmentPrecisionParametersList from './modules/equipmentNew/EquipmentPrecisionParametersList'
import '@/assets/less/TableExpand.less'
import JSearchSelectTag from '../../components/dict/JSearchSelectTag.vue'

export default {
  name: "EquipmentList",
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    JSearchSelectTag,
  },
  data() {
    return {
      description: '生产设备自主维护点检表',
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        // {
        //   title: '设备类型',
        //   align: "center",
        //   dataIndex: 'categoryName',
        // },
        {
          title: '统一编码',
          align: "center",
          dataIndex: 'equipmentNum',
          width: 150,
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName',
          width: 150,
        },
        {
          title: '型号',
          align: "center",
          dataIndex: 'equipmentModel',
          width: 150,
        },
        {
          title: '点检项目',
          align: "center",
          dataIndex: 'name',
        },
        {
          title: '完成数据/要求',
          align: "center",
          dataIndex: 'detectionStandard',
        },
        {
          title: '1',
          align: "center",
          dataIndex: '01',
          width: 50,
        },
        {
          title: '2',
          align: "center",
          dataIndex: '02',
          width: 50,
        },
        {
          title: '3',
          align: "center",
          dataIndex: '03',
          width: 50,
          // scopedSlots: { customRender: 'yseNoPrecisionParameters' }
        },
        {
          title: '4',
          align: "center",
          dataIndex: '04',
          width: 50,
          // scopedSlots: { customRender: 'yseNoInspectionStandard' }
        },
        {
          title: '5',
          align: "center",
          dataIndex: '05',
          // scopedSlots: { customRender: 'yseNoMaintenance2Standard' }
          width: 50,
        },
        {
          title: '6',
          align: "center",
          dataIndex: '06',
          width: 50,
        },
        {
          title: '7',
          align: "center",
          dataIndex: '07',
          width: 50,
        },
        {
          title: '8',
          align: "center",
          dataIndex: '08',
          width: 50,
        },
        {
          title: '9',
          align: "center",
          dataIndex: '09',
          width: 50,
        },
        {
          title: '10',
          align: "center",
          dataIndex: '10',
          width: 50,
        },
        {
          title: '11',
          align: "center",
          dataIndex: '11',
          width: 50,
        },
        {
          title: '12',
          align: "center",
          dataIndex: '12',
          width: 50,
        },
        {
          title: '13',
          align: "center",
          dataIndex: '13',
          width: 50,
        },
        {
          title: '14',
          align: "center",
          dataIndex: '14',
          width: 50,
        },
        {
          title: '15',
          align: "center",
          dataIndex: '15',
          width: 50,
        },
        {
          title: '16',
          align: "center",
          dataIndex: '16',
          width: 50,
        },
        {
          title: '17',
          align: "center",
          dataIndex: '17',
          width: 50,
        },
        {
          title: '18',
          align: "center",
          dataIndex: '18',
          width: 50,
        },
        {
          title: '19',
          align: "center",
          dataIndex: '19',
          width: 50,
        },
        {
          title: '20',
          align: "center",
          dataIndex: '20',
          width: 50,
        },
        {
          title: '21',
          align: "center",
          dataIndex: '21',
          width: 50,
        },
        {
          title: '22',
          align: "center",
          dataIndex: '22',
          width: 50,
        },
        {
          title: '23',
          align: "center",
          dataIndex: '23',
          width: 50,
        },
        {
          title: '24',
          align: "center",
          dataIndex: '24',
          width: 50,
        },
        {
          title: '25',
          align: "center",
          dataIndex: '25',
          width: 50,
        },
        {
          title: '26',
          align: "center",
          dataIndex: '26',
          width: 50,
        },
        {
          title: '27',
          align: "center",
          dataIndex: '27',
          width: 50,
        },
        {
          title: '28',
          align: "center",
          dataIndex: '28',
          width: 50,
        },
        {
          title: '29',
          align: "center",
          dataIndex: '29',
          width: 50,
        },
        {
          title: '30',
          align: "center",
          dataIndex: '30',
          width: 50,
        },
        {
          title: '31',
          align: "center",
          dataIndex: '31',
          width: 50,
        },
      ],
      columns2: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '设备类型',
          align: "center",
          dataIndex: 'categoryName',
        },
        {
          title: '统一编码',
          align: "center",
          dataIndex: 'equipmentNum',
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName',
        },
        {
          title: '型号',
          align: "center",
          dataIndex: 'equipmentModel',
        },
        {
          title: '使用部门',
          align: "center",
          dataIndex: 'departName',
        },
        {
          title: 'ABC标识',
          align: "center",
          dataIndex: 'abc',
        },
        {
          title: '关键设备标识',
          align: "center",
          dataIndex: 'specificEquipment',
        },
        {
          title: '技术状态',
          align: "center",
          dataIndex: 'technologyStatus',
        },
      ],
      url: {
        list: "/eam/inspectionOrder/findInspectionProjectList",
      },
      dictOptions: {
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 20,
        pageSizeOptions: ['5', '10', '20', '50'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      // selectedMainId: '',
      // // superFieldList: [],
      // equipmentProcessParametersMainId: '',
      // equipmentDocumentMainId: '',
      // equipmentPrecisionParametersMainId: '',
      // precisionParametersTemplateId: '',
      // isOpenPrecision: true,
      // isOpenProcess: true,
      // treeData: [],
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      mainId: '',
    }
  },
  created() {
    // this.getSuperFieldList();
    // this.initOptions();
  },
  // computed: {
  //   importExcelUrl: function () {
  //     return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
  //   }
  // },
  methods: {
    // clickThenSelect(record) {
    //   return {
    //     on: {
    //       click: () => {
    //         this.onSelectChange(record.id.split(","), [record]);
    //       }
    //     }
    //   }
    // },
    onClearSelected() {
      this.selectedRowKeys = [];
      this.selectionRows = [];
      // this.selectedMainId = ''
    },
    // onSelectChange(selectedRowKeys, selectionRows) {
    //   if (selectedRowKeys.length == 1) {
    //     this.selectedMainId = selectedRowKeys[0]
    //     this.precisionParametersTemplateId = selectionRows[0].precisionParametersTemplateId;
    //     // this.isOpenProcess = selectionRows[0].processParameters == 1;
    //     this.isOpenPrecision = selectionRows[0].precisionParameters == 1;
    //   } else {
    //     this.selectedMainId = ''
    //     this.precisionParametersTemplateId = ''
    //   }
    //   this.selectedRowKeys = selectedRowKeys;
    //   this.selectionRows = selectionRows;
    // },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      this.onClearSelected()
      var params = this.getQueryParams();//查询条件
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          // this.dataSource = res.result.records;
          this.dataSource = res.result;
          this.ipagination.total = res.result.total;
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false;
      })
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>